@@ -1,7 +1,7 @@
 package Data::Clean::JSON;
 
 our $DATE = '2018-10-09'; # DATE
-our $VERSION = '0.390'; # VERSION
+our $VERSION = '0.391'; # VERSION
 
 use 5.010001;
 use strict;
@@ -67,7 +67,7 @@ Data::Clean::JSON - Clean data so it is safe to output to JSON
 
 =head1 VERSION
 
-This document describes version 0.390 of Data::Clean::JSON (from Perl distribution Data-Clean-JSON), released on 2018-10-09.
+This document describes version 0.391 of Data::Clean::JSON (from Perl distribution Data-Clean-JSON), released on 2018-10-09.
 
 =head1 SYNOPSIS
 
@@ -115,6 +115,19 @@ default:
 
 =item * Clone circular references
 
+With a default limit of 1, meaning that if a reference is first seen again for
+the first time, it will be cloned. But if it is seen again for the second time,
+it will be replaced with "CIRCULAR".
+
+To change the default limit, customize your cleanser object:
+
+ $cleanser = Data::Clean::JSON->new(
+     -circular => ["clone", 4],
+ );
+
+or you can perform other action for circular references, see L<Data::Clean> for
+more details.
+
 =item * Unbless other types of objects
 
 =back
